@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Premailer processes HTML and CSS to improve e-mail deliverability.
 #
 # Premailer's main function is to render all CSS as inline <tt>style</tt>
@@ -15,7 +16,7 @@
 # fout.close
 #
 # # Write the plain-text output
-# fout = File.open("ouput.txt", "w")
+# fout = File.open("output.txt", "w")
 # fout.puts premailer.to_plain_text
 # fout.close
 #
@@ -141,7 +142,7 @@ class Premailer
   include Warnings
 
   # Waning level names
-  WARN_LABEL = %w(NONE SAFE POOR RISKY)
+  WARN_LABEL = ['NONE', 'SAFE', 'POOR', 'RISKY']
 
   # Create a new Premailer object.
   #
@@ -168,7 +169,8 @@ class Premailer
   # @option options [Boolean] :preserve_reset Whether to preserve styles associated with the MailChimp reset code. Default is true.
   # @option options [Boolean] :with_html_string Whether the html param should be treated as a raw string. Default is false.
   # @option options [Boolean] :verbose Whether to print errors and warnings to <tt>$stderr</tt>.  Default is false.
-  # @option options [Boolean] :io_exceptions Throws exceptions on I/O errors.
+  # @option options [Boolean] :io_exceptions Throws exceptions on I/O errors. Default is false.
+  # @option options [Boolean] :rule_set_exceptions Throws exceptions on invalid values in CSS Parser rule sets. Default is true.
   # @option options [Boolean] :include_link_tags Whether to include css from <tt>link rel=stylesheet</tt> tags.  Default is true.
   # @option options [Boolean] :include_style_tags Whether to include css from <tt>style</tt> tags.  Default is true.
   # @option options [String] :input_encoding Manually specify the source documents encoding. This is a good idea. Default is ASCII-8BIT.
@@ -178,7 +180,7 @@ class Premailer
   # @option options [String] :output_encoding Output encoding option for Nokogiri adapter. Should be set to "US-ASCII" to output HTML entities instead of Unicode characters.
   # @option options [Boolean] :create_shorthands Combine several properties into a shorthand one, e.g. font: style weight size. Default is true.
   # @option options [Boolean] :html_fragment Handle HTML fragment without any HTML content wrappers. Default is false.
-  # @option options [Boolean] :drop_unmergeable_css_rules Do not include unmergeable css rules in a <tt><style><tt> tag. Default is false.  
+  # @option options [Boolean] :drop_unmergeable_css_rules Do not include unmergeable css rules in a <tt><style><tt> tag. Default is false.
   def initialize(html, options = {})
     @options = {:warn_level => Warnings::SAFE,
                 :line_length => 65,
@@ -200,6 +202,7 @@ class Premailer
                 :verbose => false,
                 :debug => false,
                 :io_exceptions => false,
+                :rule_set_exceptions => true,
                 :include_link_tags => true,
                 :include_style_tags => true,
                 :input_encoding => 'ASCII-8BIT',
@@ -210,8 +213,7 @@ class Premailer
                 :create_shorthands => true,
                 :html_fragment => false,
                 :adapter => Adapter.use,
-                :drop_unmergeable_css_rules => false
-                }.merge(options)
+                :drop_unmergeable_css_rules => false}.merge(options)
 
     @html_file = html
     @is_local_file = @options[:with_html_string] || Premailer.local_data?(html)
@@ -233,7 +235,8 @@ class Premailer
     @css_parser = CssParser::Parser.new({
       :absolute_paths => true,
       :import => true,
-      :io_exceptions => @options[:io_exceptions]
+      :io_exceptions => @options[:io_exceptions],
+      :rule_set_exceptions => @options[:rule_set_exceptions]
     })
 
     @adapter_class = Adapter.find @options[:adapter]
@@ -261,11 +264,11 @@ class Premailer
 
 protected
   def load_css_from_local_file!(path)
-    css_block = ''
-    path.gsub!(/\Afile:/, '')
+    css_block = +''
+    path.delete_prefix!('file:')
     begin
       File.open(path, "r") do |file|
-        while line = file.gets
+        while (line = file.gets)
           css_block << line
         end
       end
@@ -352,11 +355,12 @@ public
     media_types.split(/[\s]+|,/).any? { |media_type| media_type.strip =~ /screen|handheld|all/i }
   end
 
-  def append_query_string(doc, qs)
-    return doc if qs.nil?
+  def append_query_string(doc, queries)
+    return doc if queries.nil?
 
-    qs.to_s.gsub!(/^[\?]*/, '').strip!
-    return doc if qs.empty?
+    queries = +queries
+    queries.to_s.gsub!(/^[\?]*/, '').strip!
+    return doc if queries.empty?
 
     begin
       current_host = @base_url.host
@@ -364,18 +368,18 @@ public
       current_host = nil
     end
 
-    $stderr.puts "Attempting to append_query_string: #{qs}" if @options[:verbose]
+    $stderr.puts "Attempting to append_query_string: #{queries}" if @options[:verbose]
 
-    doc.search('a').each do|el|
+    doc.search('a').each do |el|
       href = el.attributes['href'].to_s.strip
       next if href.nil? or href.empty?
 
-      next if href[0,1] =~ /[\#\{\[\<\%]/ # don't bother with anchors or special-looking links
+      next if /[\#\{\[\<\%]/.match?(href[0,1]) # don't bother with anchors or special-looking links
 
       begin
         href = Addressable::URI.parse(href)
 
-        if current_host and href.host != nil and href.host != current_host
+        if current_host and !href.host.nil? and href.host != current_host
           $stderr.puts "Skipping append_query_string for: #{href.to_s} because host is no good" if @options[:verbose]
           next
         end
@@ -387,9 +391,9 @@ public
 
         if href.query and not href.query.empty?
           amp = @options[:unescaped_ampersand] ? '&' : '&amp;'
-          href.query = href.query + amp + qs
+          href.query = href.query + amp + queries
         else
-          href.query = qs
+          href.query = queries
         end
 
         el['href'] = href.to_s
@@ -432,11 +436,11 @@ public
       tags.each do |tag|
         # skip links that look like they have merge tags
         # and mailto, ftp, etc...
-        if tag.attributes[attribute].to_s =~ /^([\%\<\{\#\[]|data:|tel:|file:|sms:|callto:|facetime:|mailto:|ftp:|gopher:|cid:)/i
+        if /^([\%\<\{\#\[]|data:|tel:|file:|sms:|callto:|facetime:|mailto:|ftp:|gopher:|cid:)/i.match?(tag.attributes[attribute].to_s)
           next
         end
 
-        if tag.attributes[attribute].to_s =~ /^http/i
+        if /^http/i.match?(tag.attributes[attribute].to_s)
           begin
             merged = Addressable::URI.parse(tag.attributes[attribute])
           rescue; next; end
@@ -470,9 +474,10 @@ public
 
   # @private
   def self.resolve_link(path, base_path) # :nodoc:
+    path = +path
     path.strip!
     resolved = nil
-    if path =~ /\A(?:(https?|ftp|file):)\/\//i
+    if /\A(?:(https?|ftp|file):)\/\//i.match?(path)
       resolved = path
       Premailer.canonicalize(resolved)
     elsif base_path.kind_of?(Addressable::URI)
@@ -499,18 +504,13 @@ public
   def self.canonicalize(uri) # :nodoc:
     u = uri.kind_of?(Addressable::URI) ? uri : Addressable::URI.parse(uri.to_s)
     u.normalize!
-    newpath = u.path
-    while newpath.gsub!(%r{([^/]+)/\.\./?}) { |match|
-        $1 == '..' ? match : ''
-      } do end
-      newpath = newpath.gsub(%r{/\./}, '/').sub(%r{/\.\z}, '/')
-      u.path = newpath
-      u.to_s
-    end
+    u.to_s
+  end
 
   # Check <tt>CLIENT_SUPPORT_FILE</tt> for any CSS warnings
   def check_client_support # :nodoc:
-    @client_support ||= YAML::load(File.open(CLIENT_SUPPORT_FILE))
+    kwargs = Psych::VERSION >= '4' ? { aliases: true } : {}
+    @client_support ||= Psych.load(File.open(CLIENT_SUPPORT_FILE), **kwargs)
 
     warnings = []
     properties = []
