@@ -1,19 +1,29 @@
-# -*- encoding: UTF-8 -*-
-
+# frozen_string_literal: true
 require File.expand_path(File.dirname(__FILE__)) + '/helper'
 
 class TestPremailer < Premailer::TestCase
   def test_special_characters_nokogiri
-    html = 	'<p>cédille c&eacute; & garçon gar&#231;on à &agrave; &nbsp; &amp; &copy;</p>'
+    # Force encoding to ISO-8859 because strings are encoded to UTF-8 by default.
+    # After some recent changes in libxml2 bundled by Nokogiri, some html
+    # entities will be rendered as their ISO-8859-1 representation
+    html = (+"<p>c\xe9dille c&eacute; & gar\xe7on gar&#231;on \xe0 &agrave; &nbsp; &amp; &copy;</p>").force_encoding('iso-8859-1')
     premailer = Premailer.new(html, :with_html_string => true, :adapter => :nokogiri)
     premailer.to_inline_css
-    assert_equal 'c&eacute;dille c&eacute; &amp; gar&ccedil;on gar&ccedil;on &agrave; &agrave; &nbsp; &amp; &copy;', premailer.processed_doc.at('p').inner_html
+    assert_equal (+"c\xE9dille c\xE9 &amp; gar\xE7on gar\xE7on \xE0 \xE0 \xA0 &amp; \xA9").force_encoding('iso-8859-1'), premailer.processed_doc.at('p').inner_html
   end
 
   def test_special_characters_nokogiri_remote
     remote_setup('chars.html', :adapter => :nokogiri)
     @premailer.to_inline_css
-    assert_equal 'c&eacute;dille c&eacute; &amp; gar&ccedil;on gar&ccedil;on &agrave; &agrave; &nbsp; &amp; &copy;', @premailer.processed_doc.at('p').inner_html
+    # Force encoding to ISO-8859 because strings are encoded to UTF-8 by default.
+    assert_equal (+"c\xE9dille c\xE9 &amp; gar\xE7on gar\xE7on \xE0 \xE0 \xA0 &amp; \xA9").force_encoding('iso-8859-1'), @premailer.processed_doc.at('p').inner_html
+  end
+
+  def test_utf8_encoding
+    html = "<p>é &nbsp; &copy;</p>"
+    premailer = Premailer.new(html, with_html_string: true, adapter: :nokogiri, input_encoding: 'UTF-8')
+    premailer.to_inline_css
+    assert_equal 'é   ©', premailer.processed_doc.at('p').inner_html
   end
 
   #def test_cyrillic_nokogiri_remote
@@ -211,7 +221,7 @@ END_HTML
       assert_nil doc.at('#remove'), "Using: #{adapter}"
       assert_nil doc.at('#keep'), "Using: #{adapter}"
       hashed_id = doc.at('a')['href'][1..-1]
-      refute_nil doc.at("\##{hashed_id}"), "Using: #{adapter}"
+      refute_nil doc.at("##{hashed_id}"), "Using: #{adapter}"
     end
   end
 
@@ -232,12 +242,12 @@ END_HTML
   end
 
   def test_carriage_returns_as_entities
-    html = <<-html
+    html = <<-HTML
     <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
     <html>
     <body>\n\r<p>test</p>\n\r<p>test</p>
     </body></html>
-    html
+    HTML
 
     [:nokogiri, :nokogiri_fast, :nokogumbo].each do |adapter|
       pm = Premailer.new(html, :with_html_string => true, :adapter => adapter)
@@ -297,7 +307,48 @@ END_HTML
     pm.to_inline_css
     doc = pm.processed_doc
     assert_equal 'FAFAFA', doc.at('table')['bgcolor']
+  end
 
+  def test_rgb_color_without_commas_and_with_alpha_modifier
+    html = <<-END_HTML
+    <html> <head> <style>table { background-color: rgb(250 250 250 / 1); } </style>
+    <body>
+    <table> <tr> <td> Test </td> </tr> </table>
+    </body> </html>
+    END_HTML
+
+    pm = Premailer.new(html, :with_html_string => true, :rgb_to_hex_attributes => true, :remove_scripts => true, :adapter => :nokogiri)
+    pm.to_inline_css
+    doc = pm.processed_doc
+    assert_equal 'FAFAFA', doc.at('table')['bgcolor']
+  end
+
+  def test_rgb_color_without_commas_and_with_percentage_modifier
+    html = <<-END_HTML
+    <html> <head> <style>table { background-color: rgb(250 250 250 / 15%); } </style>
+    <body>
+    <table> <tr> <td> Test </td> </tr> </table>
+    </body> </html>
+    END_HTML
+
+    pm = Premailer.new(html, :with_html_string => true, :rgb_to_hex_attributes => true, :remove_scripts => true, :adapter => :nokogiri)
+    pm.to_inline_css
+    doc = pm.processed_doc
+    assert_equal 'FAFAFA', doc.at('table')['bgcolor']
+  end
+
+  def test_rgb_color_is_not_matched_without_three_color_arguments
+    html = <<-END_HTML
+    <html> <head> <style>table { background-color: rgb(111 222 / 1); } </style>
+    <body>
+    <table> <tr> <td> Test </td> </tr> </table>
+    </body> </html>
+    END_HTML
+
+    pm = Premailer.new(html, :with_html_string => true, :rgb_to_hex_attributes => true, :remove_scripts => true, :adapter => :nokogiri)
+    pm.to_inline_css
+    doc = pm.processed_doc
+    assert_equal 'rgb(111 222 / 1)', doc.at('table')['bgcolor']
   end
 
   def test_non_rgb_color
@@ -388,10 +439,10 @@ END_HTML
     pm.to_inline_css
   end
 
-  def silence_stderr(&block)
+  def silence_stderr
     orig_stderr = $stderr
     $stderr = File.open(File::NULL, 'w')
-    block.call
+    yield
   ensure
     $stderr = orig_stderr
   end
